@@ -1,14 +1,11 @@
-import json
 from importlib.resources import files
 
-import pandas as pd
-
 from . import data
 from .anticreation import get_model_of_interest, get_models_with_all_confidence_levels
 from .creation import read_supermodel_from_json
 from .gathering import GatheredModels, load_sbml_model
 
-__version__ = "0.11.6"
+__version__ = "0.11.7"
 
 
 lp_example = [
