@@ -6,30 +6,30 @@ from copy import deepcopy
 from pathlib import Path
 
 import dill
+import matplotlib.patches as mpatches
 import networkx as nx
 import pandas as pd
 from cobra.flux_analysis import pfba
 from matplotlib import pyplot as plt
-import matplotlib.patches as mpatches
-from scipy.cluster.hierarchy import linkage, leaves_list
+from scipy.cluster.hierarchy import leaves_list, linkage
 
 plt.rcParams["svg.fonttype"] = "none"
 
-from .creation import SuperModel
-from .comparison import getCoreGPR, getCoreConnections
 import seaborn as sns
+
+from .comparison import getCoreConnections, getCoreGPR
+from .creation import SuperModel
 from .drawing import (
-    draw_one_known_pathway,
-    draw_one_synt_path,
-    get_pyvis_from_nx,
+    MET_NOT_INT_GLOBAL,
+    custom_histplot,
     define_edge_features,
     define_node_features,
+    draw_one_known_pathway,
+    draw_one_synt_path,
     get_color_palette,
-    custom_histplot,
-    MET_NOT_INT_GLOBAL,
+    get_pyvis_from_nx,
 )
 
-
 GLYCOLYSIS_GLOBAL = {
     "HEX1": [("glc__D_c", "g6p_c")],
     "PGI": [("g6p_c", "f6p_c")],
@@ -133,6 +133,8 @@ def write_metabolites_production_output(
     method="single",
     linewidths=0.5,
     dpi=300,
+    fig_height=None,
+    fig_width=None,
     **kwargs,
 ):
     """Function to plot heatmap of produced or not produced metabolites.
@@ -171,30 +173,42 @@ def write_metabolites_production_output(
     else:
         out_bp_production_tab.index = out_bp_production_tab["Metabolites"]
 
-    num = out_bp_production_tab.drop(columns=["Metabolites", "Metabolite names"])
-
-    num_no_grow = num.drop(index="overall_growth", errors="ignore")
-
+    num_no_grow = out_bp_production_tab.drop(index="overall_growth", errors="ignore")
     num_no_grow = num_no_grow.astype(
-        {mod_name: "float" for mod_name in num_no_grow.columns}
+        {
+            mod_name: "float"
+            for mod_name in num_no_grow.columns
+            if mod_name not in ["Metabolites", "Metabolite names"]
+        }
     )
 
-    j = linkage(num_no_grow.values, method=method, metric=metric)
-    row_order = leaves_list(j)
-    if not column_order:
-        jt = linkage(num_no_grow.T.values, method=method, metric=metric)
-        column_order = leaves_list(jt)
-    df_plot = (
-        num_no_grow.iloc[row_order]
-        .drop(columns="Metabolites")
-        .set_index("Metabolite names")
-        .iloc[row_order]
-        .drop(columns="Metabolites")
-        .set_index("Metabolite names")[column_order]
+    clust_df = num_no_grow.drop(columns=["Metabolites", "Metabolite names"])
+    j = linkage(
+        clust_df.values,
+        method=method,
+        metric=metric,
     )
+    row_order = num_no_grow.index[leaves_list(j)]
+    met_order = num_no_grow.loc[row_order]["Metabolites"].to_list()
 
-    fig, ax = plt.subplots(figsize=(4, 5.3))
-    cbar_ax = fig.add_axes([0.05, 0.05, 0.03, 0.2])
+    if column_order is None:
+        jt = linkage(
+            clust_df.values.transpose(),
+            method=method,
+            metric=metric,
+        )
+        column_order = clust_df.columns[leaves_list(jt)]
+
+    df_plot = clust_df.loc[
+        row_order, column_order
+    ]
+
+    if fig_width is None:
+        fig_width = 0.55 * len(column_order)
+    if fig_height is None:
+        fig_height = 0.17 * len(row_order)
+    fig, ax = plt.subplots(figsize=(fig_width, fig_height))
+    cbar_ax = fig.add_axes([0.05, 0.05, 0.03, 0.1])
     fig.subplots_adjust(left=0.62, top=0.99, bottom=0.13, right=0.98)
     sns.heatmap(
         df_plot,
@@ -228,7 +242,7 @@ def write_metabolites_production_output(
         fig.savefig(f"{write_output_to_folder}/all_metabolites_production.png", dpi=dpi)
     else:
         fig.savefig(plot_file_name, dpi=dpi)
-    return [fig, row_order, column_order]
+    return [fig, met_order]
 
 
 def table_reactions_confidence(
@@ -1041,6 +1055,7 @@ def _write_pfba_mq_results(
     and_as_solid=False,
     add_original_models=True,
     dpi=300,
+    fig_height=None,
     **kwargs,
 ):
     if (draw_pfba_mq is True) and (output_folder_mq_paths_plots is None):
@@ -1105,7 +1120,7 @@ def _write_pfba_mq_results(
         if met_order is not None:
             all_met = met_order
     if met_rm_from_ptw is not None:
-        all_met = list(set(all_met) - set(met_rm_from_ptw))
+        all_met = [m for m in all_met if m not in met_rm_from_ptw]
     for m in all_met:
         if m not in met_model.keys():
             if draw_confidence:
@@ -1200,11 +1215,13 @@ def _write_pfba_mq_results(
                 index=False,
                 sep="\t",
             )
+        if fig_height is None:
+            fig_height = 0.17 * len(all_met)
         g = (
             sns.FacetGrid(
                 data=confidence_paths_tab,
                 col="Reactions/GPRs",
-                height=5.3,
+                height=fig_height,
                 aspect=0.5,
                 legend_out=True,
             )
@@ -1282,6 +1299,8 @@ def run_growth_full_flux_analysis(
     met_rm_from_ptw=None,
     id_instead_long_name=20,
     dpi=300,
+    fig_height=None,
+    fig_width=None,
     flux_threshold=0.001,
     **kwargs,
 ):
@@ -1313,6 +1332,8 @@ def run_growth_full_flux_analysis(
         column_order=column_order,
         id_instead_long_name=id_instead_long_name,
         dpi=dpi,
+        fig_height=fig_height,
+        fig_width=fig_width,
         **kwargs,
     )
     if not production_plots:
@@ -1350,6 +1371,7 @@ def run_growth_full_flux_analysis(
             met_order,
             met_rm_from_ptw,
             dpi,
+            fig_height,
             **kwargs,
         )
     return (
@@ -1389,6 +1411,8 @@ def run_metquest_results_analysis(
     met_rm_from_ptw=None,
     id_instead_long_name=20,
     dpi=300,
+    fig_height=None,
+    fig_width=None,
     **kwargs,
 ):
     if output_folder_mq_paths_plots is not None:
@@ -1496,12 +1520,17 @@ def run_metquest_results_analysis(
         column_order=column_order,
         id_instead_long_name=id_instead_long_name,
         dpi=dpi,
+        fig_height=fig_height,
+        fig_width=fig_width,
         **kwargs,
     )
     if not production_plots:
         met_order = synthes_tab_out["Metabolites"].to_list()
+        if not column_order:
+            column_order = list(synthes_tab_out.columns)
     else:
         met_order = production_plots[1]
+        column_order = production_plots[2]
     if stat_file is None:
         stat_file = output_folder + "/production_confidence_stat.tsv"
     stat_out_tab.to_csv(stat_file, sep="\t", index=False)
@@ -1525,6 +1554,7 @@ def run_metquest_results_analysis(
             met_order,
             met_rm_from_ptw,
             dpi,
+            fig_height,
             **kwargs,
         )
     return synthes_tab_out, production_plots, stat_out_tab, met_interest_mq_paths
