@@ -220,7 +220,10 @@ def define_edge_features(
 
 def get_pyvis_from_nx(g, directed, size, width=1920, height=1080):
     pyvis_graph = Network(
-        width=f"{width}px", height=f"{height}px", directed=directed, notebook=False,
+        width=f"{width}px",
+        height=f"{height}px",
+        directed=directed,
+        notebook=False,
     )
     pyvis_graph.from_nx(g)
     for n in pyvis_graph.nodes:
@@ -311,7 +314,10 @@ def draw_one_known_pathway(
         if r_id in supermodel.reactions.assembly.keys():
             r = supermodel.reactions.assembly.get(r_id)
             colname_r = define_node_features(
-                color_brewer, "single_path_r", r, n_letter,
+                color_brewer,
+                "single_path_r",
+                r,
+                n_letter,
             )
             g.add_node(
                 colname_r[0],
@@ -324,7 +330,10 @@ def draw_one_known_pathway(
                 tmp_rea = re.sub("_([cep])$", "", rea.id)
                 if rea.id in path_met:
                     colname_rea = define_node_features(
-                        color_brewer, "metabolites", rea, n_letter,
+                        color_brewer,
+                        "metabolites",
+                        rea,
+                        n_letter,
                     )
                     rea_edge = define_edge_features(
                         color_brewer,
@@ -346,12 +355,18 @@ def draw_one_known_pathway(
                     )
                     for e in rea_edge:
                         g.add_edge(
-                            e[0], e[1], color=e[2], font_color="black",
+                            e[0],
+                            e[1],
+                            color=e[2],
+                            font_color="black",
                         )
                 elif additional_met:
                     if tmp_rea not in met_not_int.keys():
                         colname_rea = define_node_features(
-                            color_brewer, "metConnect", rea, n_letter,
+                            color_brewer,
+                            "metConnect",
+                            rea,
+                            n_letter,
                         )
                         rea_edge = define_edge_features(
                             color_brewer,
@@ -394,13 +409,19 @@ def draw_one_known_pathway(
                     )
                     for e in rea_edge:
                         g.add_edge(
-                            e[0], e[1], color=e[2], font_color="black",
+                            e[0],
+                            e[1],
+                            color=e[2],
+                            font_color="black",
                         )
             for pro in r.products.get("assembly"):
                 tmp_pro = re.sub("_([cep])$", "", pro.id)
                 if pro.id in path_met:
                     colname_pro = define_node_features(
-                        color_brewer, "metabolites", pro, n_letter,
+                        color_brewer,
+                        "metabolites",
+                        pro,
+                        n_letter,
                     )
                     pro_edge = define_edge_features(
                         color_brewer,
@@ -422,12 +443,18 @@ def draw_one_known_pathway(
                     )
                     for e in pro_edge:
                         g.add_edge(
-                            e[0], e[1], color=e[2], font_color="black",
+                            e[0],
+                            e[1],
+                            color=e[2],
+                            font_color="black",
                         )
                 elif additional_met:
                     if tmp_pro not in met_not_int.keys():
                         colname_pro = define_node_features(
-                            color_brewer, "metConnect", pro, n_letter,
+                            color_brewer,
+                            "metConnect",
+                            pro,
+                            n_letter,
                         )
                         pro_edge = define_edge_features(
                             color_brewer,
@@ -470,7 +497,10 @@ def draw_one_known_pathway(
                     )
                     for e in pro_edge:
                         g.add_edge(
-                            e[0], e[1], color=e[2], font_color="black",
+                            e[0],
+                            e[1],
+                            color=e[2],
+                            font_color="black",
                         )
             if genes:
                 g_colname = define_node_features(
@@ -489,7 +519,10 @@ def draw_one_known_pathway(
                     title=g_colname[3],
                 )
                 g.add_edge(
-                    r_id, g_colname[0], color=g_colname[2], font_color="black",
+                    r_id,
+                    g_colname[0],
+                    color=g_colname[2],
+                    font_color="black",
                 )
         else:
             not_f_col = color_brewer["notFound"][
@@ -536,13 +569,19 @@ def draw_one_known_pathway(
                     title=colname_pro[3],
                 )
                 g.add_edge(
-                    colname_rea[1], r_id, color=not_f_col, font_color="black",
+                    colname_rea[1],
+                    r_id,
+                    color=not_f_col,
+                    font_color="black",
                 )
                 g.add_edge(
-                    r_id, colname_pro[1], color=not_f_col, font_color="black",
+                    r_id,
+                    colname_pro[1],
+                    color=not_f_col,
+                    font_color="black",
                 )
     pyvis_graph = get_pyvis_from_nx(g, directed, size, wid, hei)
-    pyvis_graph.write_html(output_name, notebook=False)
+    pyvis_graph.write_html(str(output_name), notebook=False)
     return g
 
 
@@ -574,7 +613,12 @@ def draw_one_synt_path(
     g = nx.DiGraph()
     for r_id in path:
         r = supermodel.reactions.assembly.get(r_id)
-        colname_r = define_node_features(color_brewer, "single_path_r", r, n_letter,)
+        colname_r = define_node_features(
+            color_brewer,
+            "single_path_r",
+            r,
+            n_letter,
+        )
         g.add_node(
             colname_r[0],
             label=colname_r[1],
@@ -619,7 +663,10 @@ def draw_one_synt_path(
                 else:
                     m_pallitra = "metabolites"
                 colname_rea = define_node_features(
-                    color_brewer, m_pallitra, rea, n_letter,
+                    color_brewer,
+                    m_pallitra,
+                    rea,
+                    n_letter,
                 )
                 rea_edge = define_edge_features(
                     color_brewer,
@@ -641,7 +688,10 @@ def draw_one_synt_path(
             )
             for e in rea_edge:
                 g.add_edge(
-                    e[0], e[1], color=e[2], font_color="black",
+                    e[0],
+                    e[1],
+                    color=e[2],
+                    font_color="black",
                 )
         for pro in r.products.get("assembly"):
             tmp_pro = re.sub("_([cep])$", "", pro.id)
@@ -680,7 +730,10 @@ def draw_one_synt_path(
                 else:
                     m_pallitra = "metabolites"
                 colname_pro = define_node_features(
-                    color_brewer, m_pallitra, pro, n_letter,
+                    color_brewer,
+                    m_pallitra,
+                    pro,
+                    n_letter,
                 )
                 pro_edge = define_edge_features(
                     color_brewer,
@@ -702,7 +755,10 @@ def draw_one_synt_path(
             )
             for e in pro_edge:
                 g.add_edge(
-                    e[0], e[1], color=e[2], font_color="black",
+                    e[0],
+                    e[1],
+                    color=e[2],
+                    font_color="black",
                 )
         if genes:
             g_colname = define_node_features(
@@ -721,7 +777,10 @@ def draw_one_synt_path(
                 title=g_colname[3],
             )
             g.add_edge(
-                r_id, g_colname[0], color=g_colname[2], font_color="black",
+                r_id,
+                g_colname[0],
+                color=g_colname[2],
+                font_color="black",
             )
     pyvis_graph = get_pyvis_from_nx(g, directed, size, wid, hei)
     pyvis_graph.write_html(output_name, notebook=False)
